==> haskell-monoid-subclasses-1.1.3-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monoid-subclasses.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monoid-subclasses
version:              1.1.3
visibility:           public
id:                   monoid-subclasses-1.1.3-HbCEfRm6Hf2AB5QQXIyYi3
key:                  monoid-subclasses-1.1.3-HbCEfRm6Hf2AB5QQXIyYi3
license:              BSD-3-Clause
copyright:            (c) 2013-2021 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/monoid-subclasses/
synopsis:             Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.

category:             Data, Algebra, Text
abi:                  b3495d652bf0c0c93d2955a931a19519
exposed:              True
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial Data.Monoid.GCD
    Data.Monoid.Instances.ByteString.UTF8
    Data.Monoid.Instances.CharVector Data.Monoid.Instances.Concat
    Data.Monoid.Instances.Measured Data.Monoid.Instances.Positioned
    Data.Monoid.Instances.Stateful Data.Monoid.Monus Data.Monoid.Null
    Data.Monoid.Textual Data.Semigroup.Cancellative
    Data.Semigroup.Factorial

import-dirs:          /usr/lib/ghc-9.0.2/site-local/monoid-subclasses-1.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/monoid-subclasses-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monoid-subclasses
hs-libraries:         HSmonoid-subclasses-1.1.3-HbCEfRm6Hf2AB5QQXIyYi3
depends:
    base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    primes-0.2.1.0-40IDvqpKPw7IteoZuUfZEg text-1.2.5.0
    vector-0.12.3.1-2b175nNx5wND5qcnREemcu

haddock-interfaces:
    /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock

haddock-html:         /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monoid-subclasses-1.1.3-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monoid-subclasses.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monoid-subclasses
version:              1.1.3
visibility:           public
id:                   monoid-subclasses-1.1.3-5swNSb9Oqnis2ODud4YtP
key:                  monoid-subclasses-1.1.3-5swNSb9Oqnis2ODud4YtP
license:              BSD-3-Clause
copyright:            (c) 2013-2021 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/monoid-subclasses/
synopsis:             Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.

category:             Data, Algebra, Text
abi:                  14a6565395603f258b23657f348cec76
exposed:              True
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial Data.Monoid.GCD
    Data.Monoid.Instances.ByteString.UTF8
    Data.Monoid.Instances.CharVector Data.Monoid.Instances.Concat
    Data.Monoid.Instances.Measured Data.Monoid.Instances.Positioned
    Data.Monoid.Instances.Stateful Data.Monoid.Monus Data.Monoid.Null
    Data.Monoid.Textual Data.Semigroup.Cancellative
    Data.Semigroup.Factorial

import-dirs:          /usr/lib/ghc-9.0.2/site-local/monoid-subclasses-1.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/monoid-subclasses-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monoid-subclasses
hs-libraries:         HSmonoid-subclasses-1.1.3-5swNSb9Oqnis2ODud4YtP
depends:
    base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    primes-0.2.1.0-40IDvqpKPw7IteoZuUfZEg text-1.2.5.0
    vector-0.12.3.1-Gcg3UCz39dJ4D95PpyArUc

haddock-interfaces:
    /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock

haddock-html:         /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
